\name{delColDf}
\alias{delColDf}
\title{
delColDf
}
\description{
delete a column in the data frame
}
\usage{
delColDf(df, colName)
}

\arguments{
  \item{df}{
data frame
}
\item{colName}{
name of the column to be deleted
}
}

\value{
data frame 
}
\author{
Andrea Franceschini
}