\name{coeffOfvar}
\alias{coeffOfvar}
\title{
coeffOfvar
}
\description{
coefficient of variation
}
\usage{
coeffOfvar(x)
}

\arguments{
  \item{x}{
input number
}
}
\details{
coefficient of variation
}
\value{
coefficient of variation
}
\author{
Andrea Franceschini
}